==> hussar-skins-1.0.1.jar: static/core/sys/dict/dict_info.js <==
var DictInfoDlg = {};

layui.use(['layer','form', 'HussarAjax', 'Hussar'], function() {

    var layer = layui.layer
        , form = layui.form
        , $ = layui.jquery
        , $ax = layui.HussarAjax
        , Hussar = layui.Hussar;

    /**
     * 初始化字典详情对话框
     */
    DictInfoDlg = {
        count: $("#itemSize").val(),
        dictName: '',			//字典类别的名称
        dictTypeCode:'',        //字典类别描述
        mutiString: '',		//拼接字符串内容(拼接字典条目)
        itemTemplate: $("#itemTemplate").html()
    };

    /**
     * item获取新的id
     */
    DictInfoDlg.newId = function () {
        if (this.count == undefined) {
            this.count = 0;
        }
        this.count = this.count + 1;
        return "dictItem" + this.count;
    };

    /**
     * 关闭此对话框
     */
    DictInfoDlg.close = function () {
        parent.layer.close(window.parent.Dict.layerIndex);
    };

    /**
     * 添加条目
     */
    DictInfoDlg.addItem = function () {
        $("#itemsArea").append(this.itemTemplate);
        $("#dictItem").attr("id", this.newId());
    };

    /**
     * 删除item
     */
    DictInfoDlg.deleteItem = function (event) {
        event = event ? event : window.event;
        var obj = event.srcElement ? event.srcElement : event.target;
        obj = $(obj);
        obj = obj.is('button') ? obj : obj.parent();
        obj.parent().parent().remove();
    };

    /**
     * 检查字典条目是否有空值
     */
    DictInfoDlg.checkNullDom = function () {
        var flag = true;
        $("[name='dictItem']").each(function () {
            var num = $(this).find("[name='itemNum']");
            var name = $(this).find("[name='itemName']");
            [name, num].every(function(v){
                if (!v.val().trim()){
                    flag = false;
                    v.focus();
                    return false;
                }
                return true;
            });
            if(!flag){
                return false;
            }
        });
        return flag;
    };

    //检查特殊字符
    DictInfoDlg.checkSpecials = function(doms){
        doms = Array.isArray(doms)?doms:[];
        var reg = /^[a-zA-Z0-9_\u4e00-\u9fa5\\s·]+$/;
        var flag = true;
        doms.every(function(v){
            if (!reg.test(v.val().trim())){
                flag = false;
                v.focus();
                return false;
            }
            return true;
        });
        return flag;
    };

    /**
     * 收集添加字典的数据，进行非空验证，并提交
     * isAdd是否为新增的提交，否则为修改的提交
     */
    DictInfoDlg.collectDataSubmit = function (isAdd) {

        this.mutiString = '';
        var dictNameDom = $("#dictName");
        var dictTypeCodeDom = $("#dictTypeCode");

        var checkTypeNull = function(){
            var flag = true;
            [dictTypeCodeDom, dictNameDom].every(function(v){
                if (!v.val().trim()){
                    flag = false;
                    v.focus();
                    return false;
                }
                return true;
            });
            return flag;
        };

        if(!checkTypeNull() || !DictInfoDlg.checkNullDom()){
            layer.msg("必填项不能为空！",{
                icon:5, shift:6
            });
            return false;
        }

        if(!DictInfoDlg.checkSpecials(
            [dictTypeCodeDom, dictNameDom].concat($(".dictSpecialCheck").toArray().map(function (v) {return $(v)})))
        ) {
            layer.msg("输入项不能有特殊字符！",{
                icon:5, shift:6
            });
            return false;
        }

        this.dictName = dictNameDom.val().trim();
        this.dictTypeCode = dictTypeCodeDom.val().trim();

        var checkerNum = [], checkerName = [], checker = true;
        var mutiString = "";
        //获取数据并检查重复项
        $("[name='dictItem']").each(function () {
            var num = $(this).find("[name='itemNum']").val().trim();
            var name = $(this).find("[name='itemName']").val().trim();
            if(checkerName.indexOf(name) > -1 || checkerNum.indexOf(num) > -1){
                checker = false;
                return false;
            }else{
                checkerNum.push(num);
                checkerName.push(name);
                mutiString = mutiString + (num + ":" + name + ";");
            }
        });
        if(!checker){
            layer.msg("存在值或名称重复的字典条目，请检查！",{
                icon:5, shift:6
            });
            return false;
        }
        DictInfoDlg.mutiString = mutiString;
        if(isAdd) {
            DictInfoDlg.addSubmit();
        }else{
            DictInfoDlg.editSubmit();
        }
    };


    /**
     * 提交添加字典
     */
    DictInfoDlg.addSubmit = function () {
        //提交信息
        var ajax = new $ax("/sys/dic/add", function (data) {
            data = data || {};
            if(data.code == 200){
                parent.layui.Hussar.success("添加成功！");
                window.parent.Dict.refreshTreeAndTable();
                DictInfoDlg.close();
            }else{
                Hussar.error("添加失败！（" + (data.message || '未知错误') + "）");
            }
        }, function (data) {
            Hussar.error("添加失败！（" + (data.responseJSON.message || '未知错误') + "）");
        });
        ajax.set('dictName', this.dictName);
        ajax.set('dictTypeCode', this.dictTypeCode);
        ajax.set('dictValues', this.mutiString);
        ajax.set('parentId', $("#parentId").val());
        ajax.start();
    };

    /**
     * 提交修改
     */
    DictInfoDlg.editSubmit = function () {
        var ajax = new $ax("/sys/dic/update", function (data) {
            data = data || {};
            if(data.code == 200){
                parent.layui.Hussar.success("修改成功！");
                window.parent.Dict.refreshTreeAndTable();
                DictInfoDlg.close();
            }else{
                Hussar.error("修改失败！（" + (data.message || '未知错误') + "）");
            }

        }, function (data) {
            Hussar.error("修改失败！（" + (data.responseJSON.message || '未知错误') + "）");
        });
        ajax.set('dictId', $("#dictId").val());
        ajax.set('dictTypeCode', this.dictTypeCode);
        ajax.set('dictName', this.dictName);
        ajax.set('dictValues', this.mutiString);
        ajax.start();
    };
});

==> hussar-skins-1.0.4.jar: static/core/sys/dict/dict_info.js <==
var DictInfoDlg = {};

layui.use(['layer','form', 'HussarAjax', 'Hussar'], function() {

    var layer = layui.layer
        , form = layui.form
        , $ = layui.jquery
        , $ax = layui.HussarAjax
        , Hussar = layui.Hussar;

    /**
     * 初始化字典详情对话框
     */
    DictInfoDlg = {
        count: $("#itemSize").val(),
        dictName: '',			//字典类别的名称
        dictTypeCode:'',        //字典类别描述
        mutiString: '',		//拼接字符串内容(拼接字典条目)
        itemTemplate: $("#itemTemplate").html()
    };

    /**
     * item获取新的id
     */
    DictInfoDlg.newId = function () {
        if (this.count == undefined) {
            this.count = 0;
        }
        this.count = this.count + 1;
        return "dictItem" + this.count;
    };

    /**
     * 关闭此对话框
     */
    DictInfoDlg.close = function () {
        parent.layer.close(window.parent.Dict.layerIndex);
    };

    /**
     * 添加条目
     */
    DictInfoDlg.addItem = function () {
        $("#itemsArea").append(this.itemTemplate);
        $("#dictItem").attr("id", this.newId());
    };

    /**
     * 删除item
     */
    DictInfoDlg.deleteItem = function (event) {
        event = event ? event : window.event;
        var obj = event.srcElement ? event.srcElement : event.target;
        obj = $(obj);
        obj = obj.is('button') ? obj : obj.parent();
        obj.parent().parent().remove();
    };

    /**
     * 检查字典条目是否有空值
     */
    DictInfoDlg.checkNullDom = function () {
        var flag = true;
        $("[name='dictItem']").each(function () {
            var num = $(this).find("[name='itemNum']");
            var name = $(this).find("[name='itemName']");
            [name, num].every(function(v){
                if (!v.val().trim()){
                    flag = false;
                    v.focus();
                    return false;
                }
                return true;
            });
            if(!flag){
                return false;
            }
        });
        return flag;
    };

    //检查特殊字符
    DictInfoDlg.checkSpecials = function(doms){
        doms = Array.isArray(doms)?doms:[];
        var reg = /^[a-zA-Z0-9_\u4e00-\u9fa5\\s·]+$/;
        var flag = true;
        doms.every(function(v){
            if (!reg.test(v.val().trim())){
                flag = false;
                v.focus();
                return false;
            }
            return true;
        });
        return flag;
    };

    /**
     * 收集添加字典的数据，进行非空验证，并提交
     * isAdd是否为新增的提交，否则为修改的提交
     */
    DictInfoDlg.collectDataSubmit = function (isAdd) {

        this.mutiString = '';
        var dictNameDom = $("#dictName");
        var dictTypeCodeDom = $("#dictTypeCode");

        var checkTypeNull = function(){
            var flag = true;
            [dictTypeCodeDom, dictNameDom].every(function(v){
                if (!v.val().trim()){
                    flag = false;
                    v.focus();
                    return false;
                }
                return true;
            });
            return flag;
        };

        if(!checkTypeNull() || !DictInfoDlg.checkNullDom()){
            layer.msg("必填项不能为空！",{
                icon:5, shift:6
            });
            return false;
        }

        if(!DictInfoDlg.checkSpecials(
            [dictTypeCodeDom, dictNameDom].concat($(".dictSpecialCheck").toArray().map(function (v) {return $(v)})))
        ) {
            layer.msg("输入项不能有特殊字符！",{
                icon:5, shift:6
            });
            return false;
        }

        this.dictName = dictNameDom.val().trim();
        this.dictTypeCode = dictTypeCodeDom.val().trim();

        var checkerNum = [], checkerName = [], checker = true;
        var mutiString = "";
        //获取数据并检查重复项
        $("[name='dictItem']").each(function () {
            var num = $(this).find("[name='itemNum']").val().trim();
            var name = $(this).find("[name='itemName']").val().trim();
            if(checkerName.indexOf(name) > -1 || checkerNum.indexOf(num) > -1){
                checker = false;
                return false;
            }else{
                checkerNum.push(num);
                checkerName.push(name);
                mutiString = mutiString + (num + ":" + name + ";");
            }
        });
        if(!checker){
            layer.msg("存在值或名称重复的字典条目，请检查！",{
                icon:5, shift:6
            });
            return false;
        }
        DictInfoDlg.mutiString = mutiString;
        if(isAdd) {
            DictInfoDlg.addSubmit();
        }else{
            DictInfoDlg.editSubmit();
        }
    };


    /**
     * 提交添加字典
     */
    DictInfoDlg.addSubmit = function () {
        //提交信息
        var ajax = new $ax(Hussar.ctxPath+"/sys/dic/add", function (data) {
            data = data || {};
            if(data.code == 200){
                parent.layui.Hussar.success("添加成功！");
                window.parent.Dict.refreshTreeAndTable();
                DictInfoDlg.close();
            }else{
                Hussar.error("添加失败！（" + (data.message || '未知错误') + "）");
            }
        }, function (data) {
            Hussar.error("添加失败！（" + (data.responseJSON.message || '未知错误') + "）");
        });
        ajax.set('dictName', this.dictName);
        ajax.set('dictTypeCode', this.dictTypeCode);
        ajax.set('dictValues', this.mutiString);
        ajax.set('parentId', $("#parentId").val());
        ajax.start();
    };

    /**
     * 提交修改
     */
    DictInfoDlg.editSubmit = function () {
        var ajax = new $ax(Hussar.ctxPath+"/sys/dic/update", function (data) {
            data = data || {};
            if(data.code == 200){
                parent.layui.Hussar.success("修改成功！");
                window.parent.Dict.refreshTreeAndTable();
                DictInfoDlg.close();
            }else{
                Hussar.error("修改失败！（" + (data.message || '未知错误') + "）");
            }

        }, function (data) {
            Hussar.error("修改失败！（" + (data.responseJSON.message || '未知错误') + "）");
        });
        ajax.set('dictId', $("#dictId").val());
        ajax.set('dictTypeCode', this.dictTypeCode);
        ajax.set('dictName', this.dictName);
        ajax.set('dictValues', this.mutiString);
        ajax.start();
    };
});
